@@ -3,14 +3,22 @@ import mediapipe as mp
 import time
 
 
-class FaceDetector():
+class FaceDetector:
     def __init__(self, minDetectionCon=0.5):
         self.minDetectionCon = minDetectionCon
         self.mp_face_detection = mp.solutions.face_detection
         self.mp_drawing = mp.solutions.drawing_utils
         self.face_detection = self.mp_face_detection.FaceDetection(self.minDetectionCon)
 
-    def findFaces(self, img, draw=True, TextColor=(255, 0, 255)):
+    def findFaces(self, img, drawRect=True, showPercentage=True, textColor=(255, 0, 255)):
+        """
+        Finds faces to detect in a BGR image or from a webcam.
+        :param img: Image to find the faces to detect.
+        :param drawRect: Flag to draw the Rectangle around Faces.
+        :param showPercentage: Flag to show the accuracy percentage.
+        :param textColor: Color of the percentage's text to display.
+        :return: Image with or without drawings and bounding box info.
+        """
         imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
         self.results = self.face_detection.process(imgRGB)
         bboxs = []
@@ -21,10 +29,11 @@ class FaceDetector():
                 ih, iw, ic = img.shape
                 bbox = int(bboxC.xmin * iw), int(bboxC.ymin * ih), int(bboxC.width * iw), int(bboxC.height * ih)
                 bboxs.append([bbox, detection.score])
-                if draw:
+                if drawRect:
                     img = self.fancyDraw(img, bbox)
+                if showPercentage:
                     cv2.putText(img, f' {int(detection.score[0] * 100)} %',
-                                (bbox[0], bbox[1] - 20), cv2.FONT_HERSHEY_PLAIN, 2, TextColor, 2)
+                                (bbox[0], bbox[1] - 20), cv2.FONT_HERSHEY_PLAIN, 2, textColor, 2)
         return img, bboxs
 
     def fancyDraw(self, img, bbox, l=30, t=3, rt=1):
@@ -56,14 +65,16 @@ def main():
     detector = FaceDetector(minDetectionCon=0.85)
     while True:
         success, img = cap.read()
-        img, bboxs = detector.findFaces(img)
+        img = cv2.cv2.flip(img, 1)
+        img, bboxs = detector.findFaces(img, showPercentage=False)
         print(bboxs)
         cTime = time.time()
         fps = 1 / (cTime - pTime)
         pTime = cTime
         cv2.putText(img, f'FPS: {int(fps)}', (20, 70), cv2.FONT_HERSHEY_PLAIN, 3, (0, 255, 0), 3)
-        cv2.imshow('MediaPipe Face Detection', img)
-        cv2.waitKey(1)
+        cv2.imshow('Image', img)
+        if cv2.waitKey(1) & 0xFF == ord('q'):
+            break
 
 
 if __name__ == "__main__":
