@@ -4,19 +4,26 @@ import time
 
 
 class FaceMeshDetector():
-    def __init__(self, staticMode=False, maxFaces=1, minDetectionCon=0.5, minTrackCon=0.5):
+    def __init__(self, staticMode=False, maxFaces=1, redefineLandmarks=True, minDetectionCon=0.5, minTrackCon=0.5):
         self.staticMode = staticMode
         self.maxFaces = maxFaces
+        self.redefineLandmarks = redefineLandmarks
         self.minDetectionCon = minDetectionCon
         self.minTrackCon = minTrackCon
 
         self.mpDraw = mp.solutions.drawing_utils
         self.mpFaceMesh = mp.solutions.face_mesh
-        self.faceMesh = self.mpFaceMesh.FaceMesh(self.staticMode, self.maxFaces,
+        self.faceMesh = self.mpFaceMesh.FaceMesh(self.staticMode, self.maxFaces, self.redefineLandmarks,
                                                  self.minDetectionCon, self.minTrackCon)
         self.drawSpec = self.mpDraw.DrawingSpec(thickness=1, circle_radius=1)
 
     def findFaceMesh(self, img, draw=True):
+        """
+        Finds faces to draw face mesh in a BGR image or in a webcam.
+        :param img: Image to find the face mesh in.
+        :param draw: Flag to draw the face mesh connections.
+        :return: Image with or without drawings and faces.
+        """
         self.imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
         self.results = self.faceMesh.process(self.imgRGB)
         faces = []
@@ -45,6 +52,7 @@ def main():
     pTime = 0
     while True:
         success, img = cap.read()
+        img = cv2.cv2.flip(img, 1)
         img, faces = detector.findFaceMesh(img)
         if len(faces) != 0:
             print(faces[0])
@@ -53,8 +61,9 @@ def main():
         pTime = cTime
         cv2.putText(img, f'FPS: {int(fps)}', (20, 70), cv2.FONT_HERSHEY_PLAIN, 3, (0, 255, 0), 3)
         cv2.imshow("Image", img)
-        cv2.waitKey(1)
+        if cv2.waitKey(1) & 0xFF == ord('q'):
+            break
 
 
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
