@@ -8,8 +8,9 @@ class HandDetector:
     Finds Hands using the mediapipe library. Exports the landmarks
     in pixel format. Adds extra functionalities like finding how
     many fingers are up or the distance between two fingers. Also
-    draw bounding box around hand found.
+    provides bounding box info of the hand found.
     """
+
     def __init__(self, mode=False, maxHands=2, detectionCon=0.5, minTrackCon=0.5):
         """
         :param mode: In static mode, detection is done on each image: slower
@@ -23,40 +24,23 @@ class HandDetector:
         self.minTrackCon = minTrackCon
 
         self.mpHands = mp.solutions.hands
-        self.hands = self.mpHands.Hands(self.mode, self.maxHands,
-                                        self.detectionCon, self.minTrackCon)
+        self.hands = self.mpHands.Hands(static_image_mode=self.mode, max_num_hands=self.maxHands,
+                                        min_detection_confidence=self.detectionCon,
+                                        min_tracking_confidence=self.minTrackCon)
         self.mpDraw = mp.solutions.drawing_utils
         self.tipIds = [4, 8, 12, 16, 20]
         self.fingers = []
         self.lmList = []
 
-    def findHands(self, img, draw=True):
+    def findHands(self, img, draw=True, flipType=True, bBox=False, showHandType=False):
         """
         Finds hands in a BGR image.
         :param img: Image to find the hands in.
-        :param draw: Flag to draw the output on the image.
-        :return: Image with or without drawings
-        """
-        imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-        self.results = self.hands.process(imgRGB)
-
-        if self.results.multi_hand_landmarks:
-            for handLms in self.results.multi_hand_landmarks:
-                if draw:
-                    self.mpDraw.draw_landmarks(img, handLms,
-                                               self.mpHands.HAND_CONNECTIONS)
-        return img
-
-    def findMultipleHands(self, img, draw=True,
-                          drawBbox=False, ShowHandType=False, flipType=True):
-        """
-        Finds hands in a BGR image.
-        :param img: Image from webcam input to find hands in.
         :param draw: Flag to draw the hand connections.
-        :param drawBbox: Flag to draw the bounding box around the hands.
-        :param ShowHandType: Flag to show the hand type of a hand either it is right hand or left hand.
-        :param flipType: Flag to flip the type of hand. Left will become Right and Right will become Left
-        :return: Image with or without drawings
+        :param flipType: Flag to flip the hand type.
+        :param bBox: Flag to draw the bounding box around the hand.
+        :param showHandType: Flag to show type of hand (left or right).
+        :return: Image with or without drawings.
         """
         imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
         self.results = self.hands.process(imgRGB)
@@ -75,7 +59,6 @@ class HandDetector:
                     xList.append(px)
                     yList.append(py)
 
-
                 ## bbox
                 xmin, xmax = min(xList), max(xList)
                 ymin, ymax = min(yList), max(yList)
@@ -101,56 +84,17 @@ class HandDetector:
                 if draw:
                     self.mpDraw.draw_landmarks(img, handLms,
                                                self.mpHands.HAND_CONNECTIONS)
-                if drawBbox:
+                if bBox:
                     cv2.rectangle(img, (bbox[0] - 20, bbox[1] - 20),
                                   (bbox[0] + bbox[2] + 20, bbox[1] + bbox[3] + 20),
                                   (255, 0, 255), 2)
-                if ShowHandType:
+                if showHandType:
                     cv2.putText(img, myHand["type"], (bbox[0] - 30, bbox[1] - 30), cv2.FONT_HERSHEY_PLAIN,
                                 2, (255, 0, 255), 2)
-        return allHands, img
+        if draw:
+            return allHands, img
 
-    def findPosition(self, img, handNo=0, draw=True, drawBbox=False):
-        """
-        Finds landmarks of a single hand and puts them in a list
-        in pixel format. Also finds the bounding box around the hand.
-        :param img: main image to find hand in
-        :param handNo: hand id if more than one hand detected
-        :param draw: Flag to draw the output on the image.
-        :param drawBbox: Flag to draw the bounding box around the hands.
-        :return: list of landmarks in pixel format; bounding box
-        """
-        xList = []
-        yList = []
-        bbox = []
-        bboxInfo = []
-        self.lmList = []
-        if self.results.multi_hand_landmarks:
-            myHand = self.results.multi_hand_landmarks[handNo]
-            for id, lm in enumerate(myHand.landmark):
-                h, w, c = img.shape
-                px, py = int(lm.x * w), int(lm.y * h)
-                xList.append(px)
-                yList.append(py)
-                self.lmList.append([px, py])
-                if draw:
-                    cv2.circle(img, (px, py), 5, (255, 0, 255), cv2.FILLED)
-            xmin, xmax = min(xList), max(xList)
-            ymin, ymax = min(yList), max(yList)
-            boxW, boxH = xmax - xmin, ymax - ymin
-            bbox = xmin, ymin, boxW, boxH
-            cx, cy = bbox[0] + (bbox[2] // 2), \
-                     bbox[1] + (bbox[3] // 2)
-            bboxInfo = {"id": id, "bbox": bbox, "center": (cx, cy)}
-
-            if drawBbox:
-                cv2.rectangle(img, (bbox[0] - 20, bbox[1] - 20),
-                              (bbox[0] + bbox[2] + 20, bbox[1] + bbox[3] + 20),
-                              (0, 255, 0), 2)
-
-        return self.lmList, bboxInfo
-
-    def MultiHandFingersUp(self, myHand):
+    def fingersUp(self, myHand):
         """
         Finds how many fingers are open and returns in a list.
         Considers left and right hands separately
@@ -180,73 +124,7 @@ class HandDetector:
                     fingers.append(0)
         return fingers
 
-    def fingersUp(self):
-        """
-        Finds how many fingers are open and returns in a list.
-        Considers left and right hands separately
-        :return: List of which fingers are up
-        """
-        if self.results.multi_hand_landmarks:
-            myHandType = self.handType()
-            fingers = []
-            # Thumb
-            if myHandType == "Right":
-                if self.lmList[self.tipIds[0]][0] > self.lmList[self.tipIds[0] - 1][0]:
-                    fingers.append(1)
-                else:
-                    fingers.append(0)
-            else:
-                if self.lmList[self.tipIds[0]][0] < self.lmList[self.tipIds[0] - 1][0]:
-                    fingers.append(1)
-                else:
-                    fingers.append(0)
-
-            # 4 Fingers
-            for id in range(1, 5):
-                if self.lmList[self.tipIds[id]][1] < self.lmList[self.tipIds[id] - 2][1]:
-                    fingers.append(1)
-                else:
-                    fingers.append(0)
-        return fingers
-
-    def handType(self):
-        """
-        Checks if the hand is left or right
-        :return: "Right" or "Left"
-        """
-        if self.results.multi_hand_landmarks:
-            if self.lmList[17][0] < self.lmList[5][0]:
-                return "Right"
-            else:
-                return "Left"
-
-    def findDistance(self, p1, p2, img, draw=True):
-        """
-        Find the distance between two landmarks based on their
-        index numbers.
-        :param p1: Point1 - Index of Landmark 1.
-        :param p2: Point2 - Index of Landmark 2.
-        :param img: Image to draw on.
-        :param draw: Flag to draw the output on the image.
-        :return: Distance between the points
-                 Image with output drawn
-                 Line information
-        """
-        if self.results.multi_hand_landmarks:
-            x1, y1 = self.lmList[p1][0], self.lmList[p1][1]
-            x2, y2 = self.lmList[p2][0], self.lmList[p2][1]
-            cx, cy = (x1 + x2) // 2, (y1 + y2) // 2
-
-            if draw:
-                cv2.circle(img, (x1, y1), 5, (255, 0, 255), cv2.FILLED)
-                cv2.circle(img, (x2, y2), 5, (255, 0, 255), cv2.FILLED)
-                cv2.line(img, (x1, y1), (x2, y2), (255, 0, 255), 3)
-                cv2.circle(img, (cx, cy), 5, (255, 0, 255), cv2.FILLED)
-
-            length = math.hypot(x2 - x1, y2 - y1)
-            return length, img, [x1, y1, x2, y2, cx, cy]
-
-    def findMultiHandDistance(self, p1, p2, img, draw=True):
+    def findDistance(self, p1, p2, img=None):
         """
         Find the distance between two landmarks based on their
         index numbers.
@@ -264,30 +142,53 @@ class HandDetector:
         cx, cy = (x1 + x2) // 2, (y1 + y2) // 2
         length = math.hypot(x2 - x1, y2 - y1)
         info = (x1, y1, x2, y2, cx, cy)
-        if draw:
-            cv2.circle(img, (x1, y1), 5, (255, 0, 255), cv2.FILLED)
-            cv2.circle(img, (x2, y2), 5, (255, 0, 255), cv2.FILLED)
+        if img is not None:
+            cv2.circle(img, (x1, y1), 8, (255, 0, 255), cv2.FILLED)
+            cv2.circle(img, (x2, y2), 8, (255, 0, 255), cv2.FILLED)
             cv2.line(img, (x1, y1), (x2, y2), (255, 0, 255), 3)
-            cv2.circle(img, (cx, cy), 5, (255, 0, 255), cv2.FILLED)
-        return length, info, img
+            cv2.circle(img, (cx, cy), 8, (255, 0, 255), cv2.FILLED)
+            return length, info, img
+        else:
+            return length, info
 
 
 def main():
     cap = cv2.VideoCapture(0)
-    detector = HandDetector(detectionCon=0.85, maxHands=1)
+    detector = HandDetector(detectionCon=0.8, maxHands=2)
     while True:
         # Get image frame
         success, img = cap.read()
         # Find the hand and its landmarks
-        img = detector.findHands(img)
-        lmList, _ = detector.findPosition(img)
-        print(lmList)
+        hands, img = detector.findHands(img, flipType=False)  # with draw
+        # hands = detector.findHands(img, draw=False)  # without draw
 
+        if hands:
+            # Hand 1
+            hand1 = hands[0]
+            lmList1 = hand1["lmList"]  # List of 21 Landmark points
+            bbox1 = hand1["bbox"]  # Bounding box info x,y,w,h
+            centerPoint1 = hand1['center']  # center of the hand cx,cy
+            handType1 = hand1["type"]  # Handtype Left or Right
+
+            fingers1 = detector.fingersUp(hand1)
+
+            if len(hands) == 2:
+                # Hand 2
+                hand2 = hands[1]
+                lmList2 = hand2["lmList"]  # List of 21 Landmark points
+                bbox2 = hand2["bbox"]  # Bounding box info x,y,w,h
+                centerPoint2 = hand2['center']  # center of the hand cx,cy
+                handType2 = hand2["type"]  # Hand Type "Left" or "Right"
+
+                fingers2 = detector.fingersUp(hand2)
+
+                # Find Distance between two Landmarks. Could be same hand or different hands
+                length, info, img = detector.findDistance(lmList1[8], lmList2[8], img)  # with draw
+                # length, info = detector.findDistance(lmList1[8], lmList2[8])  # with draw
         # Display
         cv2.imshow("Image", img)
-        if cv2.waitKey(1) & 0xFF == ord('q'):
-            break
+        cv2.waitKey(1)
 
 
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
