@@ -3,3 +3,6 @@ from pycamdetector.HandTrackingModule import HandDetector
 from pycamdetector.FaceMeshModule import FaceMeshDetector
 from pycamdetector.PoseModule import poseDetector
 from pycamdetector.ObjectDetectionModule import ObjectDetector
+from pycamdetector.FPS import FPS
+from pycamdetector.Utils import imagesStack, cornerRect, findContours, \
+    PNGOverlay, imageRotate, putRectText
